E: Expectation Operator (Alias for lead)

View source: R/model-specification.R

ER Documentation

Expectation Operator (Alias for lead)

Description

A user-friendly alias for lead(x, 1). Represents the one-period-ahead model-consistent expectation of variable x.

Usage

E(x)

Arguments

x

A variable name (unquoted) within a DSGE equation formula.

Details

E(x) is equivalent to lead(x, 1). The parser translates E(x) to lead(x, 1) internally.

Value

This function is not meant to be called directly; it always throws an error. It is recognized as a syntactic marker by the equation parser inside dsge_model().

See Also

lead(), dsge_model()


dsge documentation built on Sept. 25, 2026, 5:08 p.m.