fitted.dsge_fit: Fitted values from a DSGE model

View source: R/prediction-tools.R

fitted.dsge_fitR Documentation

Fitted values from a DSGE model

Description

Returns filtered fitted values of observed variables (using all information up to and including time t).

Usage

## S3 method for class 'dsge_fit'
fitted(object, ...)

Arguments

object

A "dsge_fit" object.

...

Additional arguments (currently unused).

Value

A matrix of fitted values with columns named by observed variables.


dsge documentation built on Sept. 25, 2026, 5:08 p.m.