geweke_test: Geweke convergence diagnostic

View source: R/bayes-diagnostics.R

geweke_testR Documentation

Geweke convergence diagnostic

Description

Computes Geweke's (1992) convergence diagnostic, which compares the means of the first and last portions of each chain using a z-test.

Usage

geweke_test(object, ...)

Arguments

object

A "dsge_bayes" object.

...

Additional arguments passed to methods (e.g., frac1, frac2 for chain window fractions).

Value

An object of class "dsge_geweke" with z-scores and p-values for each parameter and chain.


dsge documentation built on Sept. 25, 2026, 5:08 p.m.