obc_constraint: Create an Occasionally Binding Constraint

View source: R/occbin.R

obc_constraintR Documentation

Create an Occasionally Binding Constraint

Description

Specifies an inequality constraint for use with simulate_occbin.

Usage

obc_constraint(variable, type = ">=", bound = 0, shock = NULL)

Arguments

variable

Character. Name of the constrained variable (must be a control variable in the model).

type

Character. Either ">=" or "<=".

bound

Numeric. The constraint bound. For models with steady state, this is in levels; for linear models, in deviations.

shock

Character or NULL. Name of the shock channel used to enforce the constraint. If NULL (default), auto-detected as the shock with the largest impact on the constrained variable.

Value

An obc_constraint object.

Examples

# Zero lower bound on nominal interest rate
obc_constraint("r", ">=", 0)

# Upper bound on debt ratio
obc_constraint("b", "<=", 0.6)


dsge documentation built on Sept. 25, 2026, 5:08 p.m.