obs: Define an Observed Control Variable Equation

View source: R/model-specification.R

obsR Documentation

Define an Observed Control Variable Equation

Description

Wraps a formula to mark it as an equation for an observed control variable in a linear DSGE model.

Usage

obs(formula)

Arguments

formula

A formula of the form variable ~ expression.

Value

A list with class "dsge_equation" containing the parsed equation and its type.

See Also

unobs(), state(), dsge_model()


dsge documentation built on Sept. 25, 2026, 5:08 p.m.