plot.dsge_decomposition: Plot Historical Shock Decomposition

View source: R/smoother.R

plot.dsge_decompositionR Documentation

Plot Historical Shock Decomposition

Description

Creates a stacked bar chart showing the contribution of each structural shock to the observed variables over time.

Usage

## S3 method for class 'dsge_decomposition'
plot(x, which = NULL, ...)

Arguments

x

A dsge_decomposition object.

which

Which observable(s) to plot. Integer or character. Default is all.

...

Additional arguments (currently unused).

Value

No return value, called for the side effect of producing stacked bar charts of the historical shock decomposition on the active graphics device.


dsge documentation built on Sept. 25, 2026, 5:08 p.m.