plot.dsge_forecast: Plot DSGE Forecasts

View source: R/plot-methods.R

plot.dsge_forecastR Documentation

Plot DSGE Forecasts

Description

Plots forecast paths for observed variables.

Usage

## S3 method for class 'dsge_forecast'
plot(x, ...)

Arguments

x

A dsge_forecast object from forecast.dsge_fit().

...

Additional arguments passed to base plotting functions.

Value

No return value, called for the side effect of producing forecast path plots on the active graphics device.


dsge documentation built on Sept. 25, 2026, 5:08 p.m.