View source: R/variance-decomposition.R
| plot.dsge_variance_decomposition | R Documentation |
For unconditional decompositions, draws a horizontal stacked bar chart showing shock shares (in percent) for each observable. For FEVD, draws one stacked-bar panel per observable with horizons on the x-axis.
## S3 method for class 'dsge_variance_decomposition'
plot(x, ...)
x |
A |
... |
Additional arguments (currently unused). |
Invisibly returns x; called for the side effect of
producing a plot.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.