View source: R/model-specification.R
| unobs | R Documentation |
Wraps a formula to mark it as an equation for an unobserved control variable in a linear DSGE model.
unobs(formula)
formula |
A formula of the form |
A list with class "dsge_equation" containing the parsed equation
and its type.
obs(), state(), dsge_model()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.