View source: R/model-specification.R
| E | R Documentation |
A user-friendly alias for lead(x, 1). Represents the one-period-ahead
model-consistent expectation of variable x.
E(x)
x |
A variable name (unquoted) within a DSGE equation formula. |
E(x) is equivalent to lead(x, 1). The parser translates E(x) to
lead(x, 1) internally.
This function is not meant to be called directly; it always
throws an error. It is recognized as a syntactic marker by the
equation parser inside dsge_model().
lead(), dsge_model()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.