View source: R/dsge-var-forecast.R
| conditional_forecast.dsge_dsgevar | R Documentation |
Produces forecasts from a DSGE-VAR posterior conditional on a user-specified path for a subset of variables. For each posterior draw of the VAR coefficients, the function applies an algorithm analogous to Waggoner-Zha (1999) at the VAR level: at each period the conditioning constraints pin down a minimum-norm sequence of VAR innovations.
## S3 method for class 'dsge_dsgevar'
conditional_forecast(object, horizon = 12L, condition, ...)
## S3 method for class 'dsge_dsgevar_mh'
conditional_forecast(object, horizon = 12L, condition, ...)
object |
A |
horizon |
Integer. Forecast horizon. |
condition |
A named list of numeric vectors (use |
... |
Additional arguments (currently unused). |
An object inheriting from dsge_forecast with posterior
summary statistics of the conditional forecast.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.