View source: R/prediction-tools.R
| fitted.dsge_fit | R Documentation |
Returns filtered fitted values of observed variables (using all information up to and including time t).
## S3 method for class 'dsge_fit'
fitted(object, ...)
object |
A |
... |
Additional arguments (currently unused). |
A matrix of fitted values with columns named by observed variables.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.