View source: R/bayes-diagnostics.R
| geweke_test | R Documentation |
Computes Geweke's (1992) convergence diagnostic, which compares the means of the first and last portions of each chain using a z-test.
geweke_test(object, ...)
object |
A |
... |
Additional arguments passed to methods (e.g., |
An object of class "dsge_geweke" with z-scores and
p-values for each parameter and chain.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.