| plot.dsge_decomposition | R Documentation |
Creates a stacked bar chart showing the contribution of each structural shock to the observed variables over time.
## S3 method for class 'dsge_decomposition'
plot(x, which = NULL, ...)
x |
A |
which |
Which observable(s) to plot. Integer or character. Default is all. |
... |
Additional arguments (currently unused). |
No return value, called for the side effect of producing stacked bar charts of the historical shock decomposition on the active graphics device.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.