| plot.dsge_forecast | R Documentation |
Plots forecast paths for observed variables.
## S3 method for class 'dsge_forecast'
plot(x, ...)
x |
A |
... |
Additional arguments passed to base plotting functions. |
No return value, called for the side effect of producing forecast path plots on the active graphics device.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.