| plot.dsge_smoothed | R Documentation |
Plot Smoothed States
## S3 method for class 'dsge_smoothed'
plot(x, which = NULL, type = c("states", "fit"), ...)
x |
A |
which |
Which states to plot. Integer vector, character vector of
state names, or |
type |
Either |
... |
Additional arguments passed to |
No return value, called for the side effect of producing smoothed state or fit plots on the active graphics device.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.