View source: R/postestimation.R
| policy_matrix | R Documentation |
Returns the policy matrix G from a fitted or solved DSGE model.
The policy matrix maps state variables to control variables:
y_t = G x_t.
policy_matrix(x, se = TRUE, level = 0.95)
x |
A |
se |
Logical. If |
level |
Confidence level for intervals. Default is 0.95. |
If se = FALSE, returns the G matrix. If se = TRUE, returns
a list with matrix, se, lower, upper, and a data frame table.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.