| smooth_shocks.dsge_solution | R Documentation |
Recovers the structural shocks from the smoothed states using the state
transition equation: \hat{\varepsilon}_{t+1} = M^+ (x_{t+1|T} - H x_{t|T})
where M^+ is the Moore-Penrose pseudo-inverse of M.
## S3 method for class 'dsge_solution'
smooth_shocks(x, data, ...)
smooth_shocks(x, ...)
## S3 method for class 'dsge_fit'
smooth_shocks(x, ...)
## S3 method for class 'dsge_bayes'
smooth_shocks(x, ...)
x |
A |
data |
Matrix or data frame of observed data with columns matching
the model's observable names. Required when |
... |
Additional arguments (currently unused). |
From the state transition x_{t+1} = H x_t + M \varepsilon_{t+1},
the smoothed innovation is x_{t+1|T} - H x_{t|T}. The structural
shocks are recovered by projecting onto M:
\hat{\varepsilon}_{t+1} = (M'M)^{-1} M' (x_{t+1|T} - H x_{t|T}).
An object of class "dsge_smoothed_shocks" containing:
(T-1) x n_shocks matrix of smoothed structural shocks.
Character vector of shock names.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.