View source: R/model-specification.R
| state | R Documentation |
Wraps a formula to mark it as an equation for a state variable in a linear DSGE model. State equations describe the evolution of state variables one period ahead.
state(formula, shock = TRUE)
formula |
A formula of the form |
shock |
Logical. If |
A list with class "dsge_equation" containing the parsed equation
and its type.
obs(), unobs(), dsge_model()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.