| steady_state | R Documentation |
Finds the steady-state values of all model variables by solving the system of nonlinear equations with all leads set equal to current values.
steady_state(model, ...)
## S3 method for class 'dsgenl_model'
steady_state(
model,
params = NULL,
guess = NULL,
maxiter = 200L,
tol = 1e-10,
...
)
model |
A |
... |
Additional arguments (currently unused). |
params |
Named numeric vector of parameter values. If |
guess |
Named numeric vector of initial guesses for variable values.
Overrides the model's |
maxiter |
Maximum Newton-Raphson iterations. Default is 200. |
tol |
Convergence tolerance. Default is 1e-10. |
An object of class "dsgenl_steady_state" with:
Named numeric vector of steady-state values.
Equation residuals at the solution.
Parameter values used.
Logical: did the solver converge?
Number of iterations used.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.